@@ -94,7 +94,7 @@ def add_vim_movement():
 
 
 PROFILE=False
-DEBUG=True
+DEBUG=False
 if DEBUG:
   debugfile = open(__name__ + ".debug", "w")
   debugfile.close()
@@ -1342,7 +1342,7 @@ class Viewer(object):
     def handle_token(token, newline, formatted_line, diff=False):
       text = token[1]
       if not text:
-        return
+        return True
 
 
       if diff and newline:
@@ -1356,12 +1356,12 @@ class Viewer(object):
             last_word = split_line[:n]
             split_line = split_line[n+1:]
 
-            if len(split_line) > 0:
-              if diff and (split_line[0] == '+' or split_line[0] == '-'):
-                formatted_line.append(highlight_token(('', split_line[0]), formatted_line))
-                split_line = split_line[1:]
+            if len(last_word) > 0:
+              if diff:
+                formatted_line.append(highlight_token((token[0], last_word), formatted_line))
+              else:
+                formatted_line.append((token[0], last_word))
 
-            formatted_line.append(last_word)
             walker.append(urwid.Text(list(formatted_line)))
             del formatted_line[:]
           else:
@@ -1371,6 +1371,8 @@ class Viewer(object):
         newline = True
       else:
         token = (token[0], clear_escape_codes(token[1]))
+        if diff and newline:
+          token = highlight_token(token, formatted_line)
         formatted_line.append(token)
         newline = False
 
